var checkBox = document.getElementById("verboseLogging");
var connectedBackend = document.getElementById("connectedBackend");
var connectedUser = document.getElementById("connectedUser");
var manualBackendUrl = document.getElementById("manualBackendUrl");
var coll = document.getElementsByClassName("collapsible");
var content = document.getElementById("content");
var logoutButton = document.getElementById("logoutButton");
var backendUrl;

var GRAVITY_PROPS = [
    "configList",
    "configListLifeTime",
    "configListCreationTime",
    "baseUrl",
    "baseUrlLifeTime",
    "baseUrlCreationTime",
    "mappingList",
    "sitesMappingsLifeTime",
    "sitesMappingsCreationTime"
];

(function () {

    document.getElementById("versionInformation").innerHTML = browser.runtime.getManifest().version;
    logoutButton.disabled = true;

    for (var i = 0; i < coll.length; i++) {
        coll[i].addEventListener("click", function () {
            this.classList.toggle("active");
            if (content.style.display === "block") {
                content.style.display = "none";
            } else {
                content.style.display = "block";
            }
        });
    }

    browser.storage.local.get(['gravityConsoleLevel', 'baseUrl', 'configList'], function (result) {
        checkBox.checked = result && result.gravityConsoleLevel;
        if (result && result.baseUrl) {
            connectedBackend.innerHTML = result.baseUrl;
            backendUrl = result.baseUrl;
            logoutButton.disabled = false;
            var xhr = new XMLHttpRequest();
            xhr.onreadystatechange = function () {
                if (xhr.readyState === 4 && xhr.status === 200) {
                    var response = JSON.parse(xhr.responseText);
                    connectedUser.innerHTML = response.login + ' <br/> ' + response.role;
                    logoutButton.disabled = false;
                } else {
                    connectedUser.innerHTML = 'not available';
                    logoutButton.disabled = true;
                }
            };
            xhr.open("GET", result.baseUrl + "services/user/info", true);
            xhr.send();
        } else {
            // disable logout
            logoutButton.disabled = true;
        }
    });

    document.addEventListener("click", function (e) {
        if (e.target.classList.contains("toggleVerboseLogging")) {
            if (checkBox.checked === true) {
                browser.storage.local.set({
                    'gravityConsoleLevel': 'verbose'
                }, function () {
                    print('Verbose logging ON.')
                });
            } else {
                browser.storage.local.remove('gravityConsoleLevel', function () {
                    print('Verbose logging OFF.')
                });
            }
        }
        if (e.target.classList.contains("wipeStorage")) {
            if (confirm('Clear extension storage? It will clear the base url and the tenant config.')) {
                browser.storage.local.remove(GRAVITY_PROPS, function () {
                    print('Local extension storage cleared: ' + GRAVITY_PROPS);
                    location.reload();
                });
            }
        }
        if (e.target.classList.contains("wipeCookies")) {
            if (confirm('This will logout the current user from gravity, sure?')) {
                deleteCookie();
            }
        }
        if (e.target.classList.contains("setBackendUrl")) {
            var container = {
                "baseUrl": manualBackendUrl.value,
                "baseUrlLifeTime": 3600000,
                "baseUrlCreationTime": new Date().getTime()
            };
            browser.storage.local.set(container, function () {
                connectedBackend.innerHTML = container.baseUrl;
                print('Backend set: ' + JSON.stringify(container));
                alert('new url is valid for 1 hour');
            });
        }

    });
})();

function print(string) {
    console.log('gravity.extensions.browser.options :: ' + string)
}

function deleteCookie() {
    var xhr = new XMLHttpRequest();
    xhr.onreadystatechange = function () {
        if (xhr.readyState === 4 && xhr.status === 200) {
            print('Cookies cleared.');
            location.reload();
        }
    };
    xhr.open("POST", backendUrl + "services/user/logout", true);
    xhr.send();
}